def major_religions():
    return [
        "Hinduism",
        "Islam",
        "Christianity",
        "Sikhism",
        "Buddhism",
        "Jainism",
        "Zoroastrianism (Parsi)",
        "Judaism",
        "Tribal / Indigenous faiths"
    ]

def hindu_festivals():
    return ["Diwali", "Holi", "Navratri", "Makar Sankranti", "Raksha Bandhan", "Janmashtami", "Dussehra"]

def islamic_festivals():
    return ["Eid al-Fitr", "Eid al-Adha", "Milad-un-Nabi", "Ramzan", "Muharram"]

def christian_festivals():
    return ["Christmas", "Easter", "Good Friday", "Palm Sunday"]

def sikh_festivals():
    return ["Guru Nanak Jayanti", "Baisakhi", "Hola Mohalla", "Gurpurab"]

def buddhist_festivals():
    return ["Buddha Purnima", "Dhamma Day", "Kathina"]

def jain_festivals():
    return ["Mahavir Jayanti", "Paryushan", "Diwali (for Mahavir's Moksha)"]

def major_languages_of_religions():
    return {
        "Hinduism": "Sanskrit, Hindi, Tamil",
        "Islam": "Urdu, Arabic",
        "Christianity": "Latin, English, Malayalam",
        "Sikhism": "Punjabi (Gurmukhi)",
        "Buddhism": "Pali, Sanskrit",
        "Jainism": "Prakrit",
        "Zoroastrianism": "Avestan, Gujarati"
    }

def classical_dance_forms():
    return [
        "Bharatanatyam", "Kathak", "Odissi", "Kuchipudi", "Mohiniyattam", 
        "Kathakali", "Manipuri", "Sattriya"
    ]

def classical_music_styles():
    return ["Hindustani", "Carnatic"]

def indian_art_styles():
    return ["Madhubani", "Warli", "Pattachitra", "Tanjore", "Miniature Paintings"]

def religious_scriptures():
    return {
        "Hinduism": "Vedas, Upanishads, Ramayana, Mahabharata, Bhagavad Gita",
        "Islam": "Quran, Hadith",
        "Christianity": "Bible",
        "Sikhism": "Guru Granth Sahib",
        "Buddhism": "Tripitaka",
        "Jainism": "Agamas",
        "Zoroastrianism": "Avesta"
    }

def places_of_worship():
    return {
        "Hinduism": "Temple",
        "Islam": "Mosque (Masjid)",
        "Christianity": "Church",
        "Sikhism": "Gurudwara",
        "Buddhism": "Monastery (Vihara)",
        "Jainism": "Derasar / Jain Temple",
        "Zoroastrianism": "Fire Temple (Agiary)"
    }

def common_cultural_symbols():
    return [
        "Om (ॐ)", "Lotus", "Trishul", "Peacock Feather", "Tilak", "Namaste Gesture",
        "Turban", "Chadar", "Saffron Robes", "Rangoli", "Aarti Plate"
    ]

def greeting_styles():
    return {
        "Hindu": "Namaste 🙏",
        "Muslim": "As-Salaam-Alaikum",
        "Christian": "Peace be with you",
        "Sikh": "Sat Sri Akal",
        "Buddhist": "Namo Buddhaya",
        "Jain": "Micchami Dukkadam"
    }

def wedding_customs():
    return {
        "Hindu": "Saptapadi (Seven vows), Sindoor, Mangalasutra",
        "Muslim": "Nikah with Mehr, Qazi officiating",
        "Christian": "Church marriage, Rings, Vows before Priest",
        "Sikh": "Anand Karaj with four Laavan hymns",
        "Buddhist": "Simple union with chants of dhamma"
    }

def food_customs():
    return [
        "Vegetarianism in Hinduism, Jainism, and Buddhism",
        "Halal food in Islam",
        "Fasting practices: Ekadashi, Ramzan, Lent, Paryushan",
        "Use of turmeric, ghee, coconut, jaggery in rituals"
    ]

def traditional_attire():
    return [
        "Sari, Kurta, Dhoti, Sherwani, Turban, Salwar Kameez, Veshti, Lungi, Dupatta, Choli"
    ]

def family_values():
    return "India values joint family systems, respect for elders, and rituals for birth, marriage, and death."

def cultural_summary():
    return """India is a land of immense religious and cultural diversity. 
From ancient Vedic traditions to tribal customs, the country represents a spiritual mosaic.
Indian culture values family, faith, festivals, food, and music. Harmony in diversity is India's cultural backbone."""