# national.py

def national_bird():
    print("Peacock")

def national_animal():
    print("Tiger")

def national_fruit():
    print("Mango")

def national_tree():
    print("Banyan Tree")

def national_flower():
    print("Lotus")

def national_river():
    print("Ganga")

def national_currency():
    print("Indian Rupee")

def national_flag():
    print("Tiranga (Tricolor)")

def national_song():
    print("Vande Mataram")

def national_anthem():
    print("Jana Gana Mana")

def national_language():
    print("Hindi")

def national_calendar():
    print("Saka Calendar")

def national_emblem():
    print("Ashoka Lion Capital")

def national_motto():
    print("Satyameva Jayate")

def national_aquatic_animal():
    print("River Dolphin")

def national_game():
    print("Hockey")

def national_dance():
    print("Bharatanatyam")

def national_monument():
    print("India Gate")

def national_symbol():
    print("Ashoka Chakra")

def national_award():
    print("Bharat Ratna")

def national_sportsperson():
    print("Major Dhyan Chand")

def national_library():
    print("National Library of India, Kolkata")

def national_scientific_body():
    print("ISRO")

def national_airline():
    print("Air India")

def national_railway():
    print("Indian Railways")

def national_capital():
    print("New Delhi")

def national_parliament():
    print("Sansad Bhavan")

def national_museum():
    print("National Museum, New Delhi")

def national_cricketer():
    print("Sachin Tendulkar")

def national_songwriter():
    print("Bankim Chandra Chatterjee")

def national_poet():
    print("Rabindranath Tagore")

def national_scientist():
    print("C. V. Raman")

def national_teacher():
    print("Dr. Sarvepalli Radhakrishnan")

def national_engineer():
    print("M. Visvesvaraya")

def national_festival():
    print("Diwali")

def national_court():
    print("Supreme Court of India")

def national_security_force():
    print("Indian Armed Forces")

def national_military_academy():
    print("National Defence Academy")

def national_temple():
    print("Meenakshi Temple")

def national_mosque():
    print("Jama Masjid")

def national_church():
    print("Basilica of Bom Jesus")

def national_handicraft():
    print("Pashmina Shawl")

def national_food():
    print("Khichdi")

def national_dessert():
    print("Rasgulla")

def national_bridge():
    print("Howrah Bridge")

def national_airport():
    print("Indira Gandhi International Airport")

def national_hill_station():
    print("Shimla")

def national_mountain_range():
    print("Himalayas")

def national_desert():
    print("Thar Desert")